==> application-boot-api-2.0.25-sources.jar: cn/com/duiba/application/boot/api/component/mappingmode/MappingModeServerConfiguration.java <==
package cn.com.duiba.application.boot.api.component.mappingmode;

import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnResource;
import org.springframework.context.annotation.Bean;
import org.springframework.core.annotation.Order;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;

public class MappingModeServerConfiguration{

    @Bean
    public MappingModeServerInterceptor mappingModeServerInterceptor(){
        return new MappingModeServerInterceptor();
    }

    @Bean
    @ConditionalOnResource(resources = "/autoconfig_xss.properties")
    public MappingModeXssDefensivePolicy mappingModeXssDefensivePolicy(){
        return new MappingModeXssDefensivePolicy();
    }

    @Bean
    @Order(-3)
    @ConditionalOnBean(MappingModeServerInterceptor.class)
    public MappingModeServerWebMvcConfigurerAdapter mappingModeServerWebMvcConfigurerAdapter(){
        return new MappingModeServerWebMvcConfigurerAdapter();
    }

    public static class MappingModeServerWebMvcConfigurerAdapter implements WebMvcConfigurer {

        @Resource
        private MappingModeServerInterceptor mappingModeServerInterceptor;

        @Override
        public void addInterceptors(InterceptorRegistry registry) {
            registry.addInterceptor(mappingModeServerInterceptor).addPathPatterns("/**");
        }

    }

}

==> application-boot-api-2.0.33-sources.jar: cn/com/duiba/application/boot/api/component/mappingmode/MappingModeServerConfiguration.java <==
package cn.com.duiba.application.boot.api.component.mappingmode;

import cn.com.duibaboot.ext.autoconfigure.security.dpefensivepolicy.XssDefensivePolicy;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.condition.ConditionalOnResource;
import org.springframework.context.annotation.Bean;
import org.springframework.core.annotation.Order;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;

/**
 * @author liuyao
 */
public class MappingModeServerConfiguration{

    @Bean
    public MappingModeServerInterceptor mappingModeServerInterceptor(){
        return new MappingModeServerInterceptor();
    }

    @Bean
    @ConditionalOnProperty(name = "duiba.security.xss.enable", havingValue="true",matchIfMissing = true)
    public MappingModeXssDefensivePolicy mappingModeXssDefensivePolicy(){
        return new MappingModeXssDefensivePolicy();
    }

    @Bean
    @Order(-3)
    @ConditionalOnBean(MappingModeServerInterceptor.class)
    public MappingModeServerWebMvcConfigurerAdapter mappingModeServerWebMvcConfigurerAdapter(){
        return new MappingModeServerWebMvcConfigurerAdapter();
    }

    public static class MappingModeServerWebMvcConfigurerAdapter implements WebMvcConfigurer {

        @Resource
        private MappingModeServerInterceptor mappingModeServerInterceptor;

        @Override
        public void addInterceptors(InterceptorRegistry registry) {
            registry.addInterceptor(mappingModeServerInterceptor).addPathPatterns("/**");
        }

    }

}
